//*****************************************************************************
//
//  (C) Copyright Cirque Corp., 1996, 1997 All rights reserved.
//
//  Title: Touchpad.h - Touchpad API
//
//  Version: 1.00
//
//*****************************************************************************

#ifndef TOUCH_PAD_API_H__
#define TOUCH_PAD_API_H__

#include <windows.h>
#include <pshpack1.h>         /* Assume byte packing throughout */

#ifdef __cplusplus
extern "C" {
#endif

#if !defined(TOUCHPADAPIDLLBUILD)
#define TOUCHPADAPI DECLSPEC_IMPORT
#else
#define TOUCHPADAPI
#endif

/* Touch Pad Flags */
#define TPF_POSTMESSAGE    0x00000000
#define TPF_SENDMESSAGE    0x00000001
#define TPF_RAW            0x00000002
#define TPF_CURSOR         0x00000004
#define TPF_INK            0x00000008

DECLARE_HANDLE(HTOUCHPAD);

enum TPDeviceType
{
   TPDeviceTypeUnknown  = 0, // Unknown device type
   TPDeviceTypeMouse    = 1, // Standard mouse or compatible
   TPDeviceTypeTouchpad = 2  // Touchpad
};

enum TPDevicePortMask
{
   TPDevicePortTypeMask = 0xFFFF0000, // Specifies the device port type
   TPDevicePortIDMask   = 0x0000FFFF  // Unique port of specified type
};

enum TPDevicePortType
{
   TPDevicePortTypeRaw   = 0x00000000,
   TPDevicePortTypeCOM   = 0x00010000,
   TPDevicePortTypePS2   = 0x00020000,
   TPDevicePortTypeUSB   = 0x00040000,
   TPDevicePortTypeOther = 0xFFFF0000
};

enum TPDevicePort
{
   TPDevicePortInvalid = 0xFFFFFFFF,
   TPDevicePortDefault = 0xFFFFFFFE,
   TPDevicePortPS2     = TPDevicePortTypePS2,
   TPDevicePortCOM1    = TPDevicePortTypeCOM | 1,
   TPDevicePortCOM2    = TPDevicePortTypeCOM | 2,
   TPDevicePortCOM3    = TPDevicePortTypeCOM | 3,
   TPDevicePortCOM4    = TPDevicePortTypeCOM | 4,
   TPDevicePortUSB1    = TPDevicePortTypeUSB | 5,
   TPDevicePortUSB2    = TPDevicePortTypeUSB | 6,
   TPDevicePortUSB3    = TPDevicePortTypeUSB | 7,
   TPDevicePortUSB4    = TPDevicePortTypeUSB | 8,
   TPDevicePortUSB5    = TPDevicePortTypeUSB | 9,
   TPDevicePortUSB6    = TPDevicePortTypeUSB | 10,
   TPDevicePortUSB7    = TPDevicePortTypeUSB | 11,
   TPDevicePortUSB8    = TPDevicePortTypeUSB | 12
};

enum TPDeviceDriver
{
   TPDeviceDriverUnknown   = 0,
   TPDeviceDriverCirque    = 1,
   TPDeviceDriverSynaptics = 2
};

enum TPScrollType
{
   TPScrollTypeNone = 0,
   TPScrollTypeScrollbar = 1,
   TPScrollTypeWheelMouse = 2
};

#pragma pack(push, 1)

typedef struct tagGenericDevice
{
   TPDeviceType deviceType;
   TPDevicePort devicePort;
   TPDeviceDriver deviceDriver;
} GENERIC_DEVICE, *LPGENERICDEVICE;

typedef struct tagFeedHdrType
{
   DWORD dwFeeds;
} FEEDHDR, *LPFEEDHDR;

// Button flags
#define TPF_LEFT     0x0001
#define TPF_RIGHT    0x0002
#define TPF_AUX      0x0004

// State flags
#define TPF_TAP       0x8000
#define TPF_DOUBLETAP 0x4000
#define TPF_DRAG      0x2000
#define TPF_DRAGLOCK  0x1000
#define TPF_PRIMGEST  0x0800
#define TPF_SECGEST   0x0400

typedef struct tagRawFeedType
{
   WORD x;         // Absolute x-coordinate (0-2047)
   WORD y;         // Absolute y-coordinate (0-1535)
   WORD wPressure; // Absolute pressure (0-128; <18 off)
   WORD wFlags;    // driver states (see above defines)
} RAWFEED, *LPRAWFEED;

typedef struct tagCursorFeedType
{
   WORD x;
   WORD y;
   WORD wPressure;
   WORD wFlags;
} CURSORFEED, *LPCURSORFEED;

typedef struct tagInkFeedType
{
   WORD x;
   WORD y;
   WORD wPressure;
   WORD wFlags;
} INKFEED, *LPINKFEED;

#pragma pack(pop)

typedef void (CALLBACK* TOUCHPADPROC)(HTOUCHPAD hTP, LPFEEDHDR lpFeedHdr, LPARAM lParam);
typedef BOOL (CALLBACK* ENUMDEVICESPROC)(LPGENERICDEVICE, LPARAM);

TOUCHPADAPI BOOL WINAPI CreateCallback(HTOUCHPAD hTP, TOUCHPADPROC lpTouchpadFunc, DWORD dwFlags, LPARAM lParam);
TOUCHPADAPI BOOL WINAPI CreateFeed(HTOUCHPAD hTP, HWND hWnd, UINT uiMsg, DWORD dwFlags);
TOUCHPADAPI BOOL WINAPI CreateNotify(HTOUCHPAD hTP, HWND hWnd, UINT uiMsg);
TOUCHPADAPI BOOL WINAPI DestroyFeed(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI DestroyNotify(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI EnableWindowsCursor(HTOUCHPAD hTP, BOOL bEnable);
TOUCHPADAPI BOOL WINAPI EnumDevices(ENUMDEVICESPROC lpDevicesFunc, LPARAM lParam);
TOUCHPADAPI BYTE WINAPI GetAcceleration(HTOUCHPAD hTP);
TOUCHPADAPI TPDevicePort WINAPI GetActiveDevice(VOID);
TOUCHPADAPI BOOL WINAPI GetData(HTOUCHPAD hTP, LPFEEDHDR lpFeedHdr, LPDWORD lpBufferSize);
TOUCHPADAPI TPDeviceType WINAPI GetDeviceType(TPDevicePort port);
TOUCHPADAPI DWORD WINAPI GetDoubleTapDuration(HTOUCHPAD hTP);
TOUCHPADAPI SHORT WINAPI GetEdgeMaxX(HTOUCHPAD hTP);
TOUCHPADAPI SHORT WINAPI GetEdgeMaxY(HTOUCHPAD hTP);
TOUCHPADAPI SHORT WINAPI GetEdgeMinX(HTOUCHPAD hTP);
TOUCHPADAPI SHORT WINAPI GetEdgeMinY(HTOUCHPAD hTP);
TOUCHPADAPI DWORD WINAPI GetFirmwareRev(HTOUCHPAD hTP);
TOUCHPADAPI SHORT WINAPI GetMaxX(HTOUCHPAD hTP);
TOUCHPADAPI SHORT WINAPI GetMaxY(HTOUCHPAD hTP);
TOUCHPADAPI SHORT WINAPI GetMinX(HTOUCHPAD hTP);
TOUCHPADAPI SHORT WINAPI GetMinY(HTOUCHPAD hTP);
TOUCHPADAPI HTOUCHPAD WINAPI GetPad(TPDevicePort port);
TOUCHPADAPI SHORT WINAPI GetPadMaxX(HTOUCHPAD hTP);
TOUCHPADAPI SHORT WINAPI GetPadMaxY(HTOUCHPAD hTP);
TOUCHPADAPI SHORT WINAPI GetPadMinX(HTOUCHPAD hTP);
TOUCHPADAPI SHORT WINAPI GetPadMinY(HTOUCHPAD hTP);
TOUCHPADAPI TPDeviceType WINAPI GetPadType(HTOUCHPAD hTP);
TOUCHPADAPI WORD WINAPI GetPressureMax(HTOUCHPAD hTP);
TOUCHPADAPI WORD WINAPI GetPressureTouch(HTOUCHPAD hTP);
TOUCHPADAPI ULONG WINAPI GetProcessedBufferSize(HTOUCHPAD hTP);
TOUCHPADAPI ULONG WINAPI GetRawBufferSize(HTOUCHPAD hTP);
TOUCHPADAPI WORD WINAPI GetRotation(HTOUCHPAD hTP);
TOUCHPADAPI WORD WINAPI GetSampleRate(HTOUCHPAD hTP);
TOUCHPADAPI BYTE WINAPI GetScrollLines(HTOUCHPAD hTP);
TOUCHPADAPI TPScrollType WINAPI GetScrollType(HTOUCHPAD hTP);
TOUCHPADAPI WORD WINAPI GetSensitivity(HTOUCHPAD hTP);
TOUCHPADAPI DWORD WINAPI GetSingleTapDuration(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI InitTouchpadAPI(VOID);
TOUCHPADAPI BOOL WINAPI IsDataZoomScrollEnabled(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI IsDragLockEnabled(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI IsDragSndEnabled(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI IsDriverPresent(VOID);
TOUCHPADAPI BOOL WINAPI IsExtRgnSndEnabled(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI IsGlideExtEnabled(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI IsHScrollEnabled(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI IsLTapSndEnabled(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI IsPenEnabled(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI IsRTapSndEnabled(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI IsTapEnabled(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI IsTouchpad(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI IsVScrollEnabled(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI IsZoomScrollEnabled(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI ReleasePad(HTOUCHPAD hTP);
TOUCHPADAPI TPDevicePort WINAPI SelectDevice(HTOUCHPAD hTP, TPDevicePort port);
TOUCHPADAPI BOOL WINAPI SetFeedResolution(HTOUCHPAD hTP, DWORD dwFeeds, BOOL bHigh);
TOUCHPADAPI BOOL WINAPI SetProcessedBufferSize(HTOUCHPAD hTP, ULONG ulSize);
TOUCHPADAPI BOOL WINAPI SetRawBufferSize(HTOUCHPAD hTP, ULONG ulSize);
TOUCHPADAPI BOOL WINAPI SetSampleRate(HTOUCHPAD hTP, WORD wRate);
TOUCHPADAPI BOOL WINAPI StartFeed(HTOUCHPAD hTP);
TOUCHPADAPI BOOL WINAPI StopFeed(HTOUCHPAD hTP);

#ifdef __cplusplus
}
#endif

#include <poppack.h>
#endif
